# Generated by Django 4.2.16 on 2024-12-12 13:27

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [
        ('eveonline', '0017_alliance_and_corp_names_are_not_unique'),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('opcalendar', '0027_eventmember_comment_eventmember_status_usersettings'),
        ('outfit418_backup_ratting', '0004_alter_general_options'),
    ]

    operations = [
        migrations.CreateModel(
            name='EventBackup',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(max_length=200)),
                ('doctrine', models.CharField(max_length=254)),
                ('formup_system', models.CharField(max_length=254)),
                ('description', models.TextField()),
                ('start_time', models.DateTimeField()),
                ('end_time', models.DateTimeField()),
                ('repeat_event', models.CharField(blank=True, choices=[('DD', 'Daily'), ('WE', 'Weekly'), ('MM', 'Monthly'), ('YY', 'Yearly')], default=False, max_length=32, null=True)),
                ('repeat_times', models.IntegerField(blank=True, default=False, null=True)),
                ('fc', models.CharField(max_length=254)),
                ('external', models.BooleanField(default=False, null=True)),
                ('created_date', models.DateTimeField(default=django.utils.timezone.now)),
                ('deleted_on', models.DateTimeField(auto_now_add=True)),
                ('eve_character', models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='eveonline.evecharacter')),
                ('event_visibility', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='opcalendar.eventvisibility')),
                ('host', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='opcalendar.eventhost')),
                ('operation_type', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, to='opcalendar.eventcategory')),
                ('user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
        ),
        migrations.CreateModel(
            name='EventMemberBackup',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('status', models.CharField(choices=[('A', 'Attending'), ('M', 'Maybe'), ('D', 'Declined')], default='A', max_length=1)),
                ('comment', models.CharField(blank=True, help_text='Optional comment about the event', max_length=100)),
                ('character', models.ForeignKey(help_text='Event creator main character', null=True, on_delete=django.db.models.deletion.SET_NULL, to='eveonline.evecharacter')),
                ('event', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='outfit418_backup_ratting.eventbackup')),
            ],
            options={
                'unique_together': {('event', 'character')},
            },
        ),
    ]
